# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/accesslog/v3/accesslog.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/accesslog/v3/accesslog.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from envoy.data.accesslog.v3 import accesslog_pb2 as envoy_dot_data_dot_accesslog_dot_v3_dot_accesslog__pb2
from envoy.type.matcher.v3 import metadata_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_metadata__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)envoy/config/accesslog/v3/accesslog.proto\x12\x19\x65nvoy.config.accesslog.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a,envoy/config/route/v3/route_components.proto\x1a\'envoy/data/accesslog/v3/accesslog.proto\x1a$envoy/type/matcher/v3/metadata.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xd3\x01\n\tAccessLog\x12\x0c\n\x04name\x18\x01 \x01(\t\x12:\n\x06\x66ilter\x18\x02 \x01(\x0b\x32*.envoy.config.accesslog.v3.AccessLogFilter\x12,\n\x0ctyped_config\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:1\x9a\xc5\x88\x1e,\n*envoy.config.filter.accesslog.v2.AccessLogB\r\n\x0b\x63onfig_typeJ\x04\x08\x03\x10\x04R\x06\x63onfig\"\xf9\x07\n\x0f\x41\x63\x63\x65ssLogFilter\x12I\n\x12status_code_filter\x18\x01 \x01(\x0b\x32+.envoy.config.accesslog.v3.StatusCodeFilterH\x00\x12\x44\n\x0f\x64uration_filter\x18\x02 \x01(\x0b\x32).envoy.config.accesslog.v3.DurationFilterH\x00\x12R\n\x17not_health_check_filter\x18\x03 \x01(\x0b\x32/.envoy.config.accesslog.v3.NotHealthCheckFilterH\x00\x12\x46\n\x10traceable_filter\x18\x04 \x01(\x0b\x32*.envoy.config.accesslog.v3.TraceableFilterH\x00\x12\x42\n\x0eruntime_filter\x18\x05 \x01(\x0b\x32(.envoy.config.accesslog.v3.RuntimeFilterH\x00\x12:\n\nand_filter\x18\x06 \x01(\x0b\x32$.envoy.config.accesslog.v3.AndFilterH\x00\x12\x38\n\tor_filter\x18\x07 \x01(\x0b\x32#.envoy.config.accesslog.v3.OrFilterH\x00\x12@\n\rheader_filter\x18\x08 \x01(\x0b\x32\'.envoy.config.accesslog.v3.HeaderFilterH\x00\x12M\n\x14response_flag_filter\x18\t \x01(\x0b\x32-.envoy.config.accesslog.v3.ResponseFlagFilterH\x00\x12I\n\x12grpc_status_filter\x18\n \x01(\x0b\x32+.envoy.config.accesslog.v3.GrpcStatusFilterH\x00\x12\x46\n\x10\x65xtension_filter\x18\x0b \x01(\x0b\x32*.envoy.config.accesslog.v3.ExtensionFilterH\x00\x12\x44\n\x0fmetadata_filter\x18\x0c \x01(\x0b\x32).envoy.config.accesslog.v3.MetadataFilterH\x00\x12\x43\n\x0flog_type_filter\x18\r \x01(\x0b\x32(.envoy.config.accesslog.v3.LogTypeFilterH\x00:7\x9a\xc5\x88\x1e\x32\n0envoy.config.filter.accesslog.v2.AccessLogFilterB\x17\n\x10\x66ilter_specifier\x12\x03\xf8\x42\x01\"\xee\x01\n\x10\x43omparisonFilter\x12\x44\n\x02op\x18\x01 \x01(\x0e\x32..envoy.config.accesslog.v3.ComparisonFilter.OpB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12<\n\x05value\x18\x02 \x01(\x0b\x32#.envoy.config.core.v3.RuntimeUInt32B\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x1c\n\x02Op\x12\x06\n\x02\x45Q\x10\x00\x12\x06\n\x02GE\x10\x01\x12\x06\n\x02LE\x10\x02:8\x9a\xc5\x88\x1e\x33\n1envoy.config.filter.accesslog.v2.ComparisonFilter\"\x97\x01\n\x10StatusCodeFilter\x12I\n\ncomparison\x18\x01 \x01(\x0b\x32+.envoy.config.accesslog.v3.ComparisonFilterB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:8\x9a\xc5\x88\x1e\x33\n1envoy.config.filter.accesslog.v2.StatusCodeFilter\"\x93\x01\n\x0e\x44urationFilter\x12I\n\ncomparison\x18\x01 \x01(\x0b\x32+.envoy.config.accesslog.v3.ComparisonFilterB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:6\x9a\xc5\x88\x1e\x31\n/envoy.config.filter.accesslog.v2.DurationFilter\"T\n\x14NotHealthCheckFilter:<\x9a\xc5\x88\x1e\x37\n5envoy.config.filter.accesslog.v2.NotHealthCheckFilter\"J\n\x0fTraceableFilter:7\x9a\xc5\x88\x1e\x32\n0envoy.config.filter.accesslog.v2.TraceableFilter\"\xc3\x01\n\rRuntimeFilter\x12\x1c\n\x0bruntime_key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x39\n\x0fpercent_sampled\x18\x02 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x12\"\n\x1ause_independent_randomness\x18\x03 \x01(\x08:5\x9a\xc5\x88\x1e\x30\n.envoy.config.filter.accesslog.v2.RuntimeFilter\"\x85\x01\n\tAndFilter\x12\x45\n\x07\x66ilters\x18\x01 \x03(\x0b\x32*.envoy.config.accesslog.v3.AccessLogFilterB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:1\x9a\xc5\x88\x1e,\n*envoy.config.filter.accesslog.v2.AndFilter\"\x83\x01\n\x08OrFilter\x12\x45\n\x07\x66ilters\x18\x02 \x03(\x0b\x32*.envoy.config.accesslog.v3.AccessLogFilterB\x08\xfa\x42\x05\x92\x01\x02\x08\x02:0\x9a\xc5\x88\x1e+\n)envoy.config.filter.accesslog.v2.OrFilter\"\x84\x01\n\x0cHeaderFilter\x12>\n\x06header\x18\x01 \x01(\x0b\x32$.envoy.config.route.v3.HeaderMatcherB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01:4\x9a\xc5\x88\x1e/\n-envoy.config.filter.accesslog.v2.HeaderFilter\"\xf3\x01\n\x12ResponseFlagFilter\x12\xa0\x01\n\x05\x66lags\x18\x01 \x03(\tB\x90\x01\xfa\x42\x8c\x01\x92\x01\x88\x01\"\x85\x01r\x82\x01R\x02LHR\x02UHR\x02UTR\x02LRR\x02URR\x02UFR\x02UCR\x02UOR\x02NRR\x02\x44IR\x02\x46IR\x02RLR\x04UAEXR\x04RLSER\x02\x44\x43R\x03URXR\x02SIR\x02IHR\x03\x44PER\x05UMSDRR\x04RFCFR\x04NFCFR\x02\x44TR\x03UPER\x02NCR\x02OMR\x02\x44\x46R\x02\x44OR\x02\x44R::\x9a\xc5\x88\x1e\x35\n3envoy.config.filter.accesslog.v2.ResponseFlagFilter\"\xed\x03\n\x10GrpcStatusFilter\x12S\n\x08statuses\x18\x01 \x03(\x0e\x32\x32.envoy.config.accesslog.v3.GrpcStatusFilter.StatusB\r\xfa\x42\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01\x12\x0f\n\x07\x65xclude\x18\x02 \x01(\x08\"\xb8\x02\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\x0c\n\x08\x43\x41NCELED\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\x12\x14\n\x10INVALID_ARGUMENT\x10\x03\x12\x15\n\x11\x44\x45\x41\x44LINE_EXCEEDED\x10\x04\x12\r\n\tNOT_FOUND\x10\x05\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x06\x12\x15\n\x11PERMISSION_DENIED\x10\x07\x12\x16\n\x12RESOURCE_EXHAUSTED\x10\x08\x12\x17\n\x13\x46\x41ILED_PRECONDITION\x10\t\x12\x0b\n\x07\x41\x42ORTED\x10\n\x12\x10\n\x0cOUT_OF_RANGE\x10\x0b\x12\x11\n\rUNIMPLEMENTED\x10\x0c\x12\x0c\n\x08INTERNAL\x10\r\x12\x0f\n\x0bUNAVAILABLE\x10\x0e\x12\r\n\tDATA_LOSS\x10\x0f\x12\x13\n\x0fUNAUTHENTICATED\x10\x10:8\x9a\xc5\x88\x1e\x33\n1envoy.config.filter.accesslog.v2.GrpcStatusFilter\"\xbd\x01\n\x0eMetadataFilter\x12\x37\n\x07matcher\x18\x01 \x01(\x0b\x32&.envoy.type.matcher.v3.MetadataMatcher\x12:\n\x16match_if_key_not_found\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue:6\x9a\xc5\x88\x1e\x31\n/envoy.config.filter.accesslog.v2.MetadataFilter\"f\n\rLogTypeFilter\x12\x44\n\x05types\x18\x01 \x03(\x0e\x32&.envoy.data.accesslog.v3.AccessLogTypeB\r\xfa\x42\n\x92\x01\x07\"\x05\x82\x01\x02\x10\x01\x12\x0f\n\x07\x65xclude\x18\x02 \x01(\x08\"\xa3\x01\n\x0f\x45xtensionFilter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:7\x9a\xc5\x88\x1e\x32\n0envoy.config.filter.accesslog.v2.ExtensionFilterB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfigB\x91\x01\n\'io.envoyproxy.envoy.config.accesslog.v3B\x0e\x41\x63\x63\x65sslogProtoP\x01ZLgithub.com/envoyproxy/go-control-plane/envoy/config/accesslog/v3;accesslogv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.accesslog.v3.accesslog_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'io.envoyproxy.envoy.config.accesslog.v3B\016AccesslogProtoP\001ZLgithub.com/envoyproxy/go-control-plane/envoy/config/accesslog/v3;accesslogv3\272\200\310\321\006\002\020\002'
  _globals['_ACCESSLOG']._loaded_options = None
  _globals['_ACCESSLOG']._serialized_options = b'\232\305\210\036,\n*envoy.config.filter.accesslog.v2.AccessLog'
  _globals['_ACCESSLOGFILTER'].oneofs_by_name['filter_specifier']._loaded_options = None
  _globals['_ACCESSLOGFILTER'].oneofs_by_name['filter_specifier']._serialized_options = b'\370B\001'
  _globals['_ACCESSLOGFILTER']._loaded_options = None
  _globals['_ACCESSLOGFILTER']._serialized_options = b'\232\305\210\0362\n0envoy.config.filter.accesslog.v2.AccessLogFilter'
  _globals['_COMPARISONFILTER'].fields_by_name['op']._loaded_options = None
  _globals['_COMPARISONFILTER'].fields_by_name['op']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_COMPARISONFILTER'].fields_by_name['value']._loaded_options = None
  _globals['_COMPARISONFILTER'].fields_by_name['value']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_COMPARISONFILTER']._loaded_options = None
  _globals['_COMPARISONFILTER']._serialized_options = b'\232\305\210\0363\n1envoy.config.filter.accesslog.v2.ComparisonFilter'
  _globals['_STATUSCODEFILTER'].fields_by_name['comparison']._loaded_options = None
  _globals['_STATUSCODEFILTER'].fields_by_name['comparison']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_STATUSCODEFILTER']._loaded_options = None
  _globals['_STATUSCODEFILTER']._serialized_options = b'\232\305\210\0363\n1envoy.config.filter.accesslog.v2.StatusCodeFilter'
  _globals['_DURATIONFILTER'].fields_by_name['comparison']._loaded_options = None
  _globals['_DURATIONFILTER'].fields_by_name['comparison']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_DURATIONFILTER']._loaded_options = None
  _globals['_DURATIONFILTER']._serialized_options = b'\232\305\210\0361\n/envoy.config.filter.accesslog.v2.DurationFilter'
  _globals['_NOTHEALTHCHECKFILTER']._loaded_options = None
  _globals['_NOTHEALTHCHECKFILTER']._serialized_options = b'\232\305\210\0367\n5envoy.config.filter.accesslog.v2.NotHealthCheckFilter'
  _globals['_TRACEABLEFILTER']._loaded_options = None
  _globals['_TRACEABLEFILTER']._serialized_options = b'\232\305\210\0362\n0envoy.config.filter.accesslog.v2.TraceableFilter'
  _globals['_RUNTIMEFILTER'].fields_by_name['runtime_key']._loaded_options = None
  _globals['_RUNTIMEFILTER'].fields_by_name['runtime_key']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_RUNTIMEFILTER']._loaded_options = None
  _globals['_RUNTIMEFILTER']._serialized_options = b'\232\305\210\0360\n.envoy.config.filter.accesslog.v2.RuntimeFilter'
  _globals['_ANDFILTER'].fields_by_name['filters']._loaded_options = None
  _globals['_ANDFILTER'].fields_by_name['filters']._serialized_options = b'\372B\005\222\001\002\010\002'
  _globals['_ANDFILTER']._loaded_options = None
  _globals['_ANDFILTER']._serialized_options = b'\232\305\210\036,\n*envoy.config.filter.accesslog.v2.AndFilter'
  _globals['_ORFILTER'].fields_by_name['filters']._loaded_options = None
  _globals['_ORFILTER'].fields_by_name['filters']._serialized_options = b'\372B\005\222\001\002\010\002'
  _globals['_ORFILTER']._loaded_options = None
  _globals['_ORFILTER']._serialized_options = b'\232\305\210\036+\n)envoy.config.filter.accesslog.v2.OrFilter'
  _globals['_HEADERFILTER'].fields_by_name['header']._loaded_options = None
  _globals['_HEADERFILTER'].fields_by_name['header']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_HEADERFILTER']._loaded_options = None
  _globals['_HEADERFILTER']._serialized_options = b'\232\305\210\036/\n-envoy.config.filter.accesslog.v2.HeaderFilter'
  _globals['_RESPONSEFLAGFILTER'].fields_by_name['flags']._loaded_options = None
  _globals['_RESPONSEFLAGFILTER'].fields_by_name['flags']._serialized_options = b'\372B\214\001\222\001\210\001\"\205\001r\202\001R\002LHR\002UHR\002UTR\002LRR\002URR\002UFR\002UCR\002UOR\002NRR\002DIR\002FIR\002RLR\004UAEXR\004RLSER\002DCR\003URXR\002SIR\002IHR\003DPER\005UMSDRR\004RFCFR\004NFCFR\002DTR\003UPER\002NCR\002OMR\002DFR\002DOR\002DR'
  _globals['_RESPONSEFLAGFILTER']._loaded_options = None
  _globals['_RESPONSEFLAGFILTER']._serialized_options = b'\232\305\210\0365\n3envoy.config.filter.accesslog.v2.ResponseFlagFilter'
  _globals['_GRPCSTATUSFILTER'].fields_by_name['statuses']._loaded_options = None
  _globals['_GRPCSTATUSFILTER'].fields_by_name['statuses']._serialized_options = b'\372B\n\222\001\007\"\005\202\001\002\020\001'
  _globals['_GRPCSTATUSFILTER']._loaded_options = None
  _globals['_GRPCSTATUSFILTER']._serialized_options = b'\232\305\210\0363\n1envoy.config.filter.accesslog.v2.GrpcStatusFilter'
  _globals['_METADATAFILTER']._loaded_options = None
  _globals['_METADATAFILTER']._serialized_options = b'\232\305\210\0361\n/envoy.config.filter.accesslog.v2.MetadataFilter'
  _globals['_LOGTYPEFILTER'].fields_by_name['types']._loaded_options = None
  _globals['_LOGTYPEFILTER'].fields_by_name['types']._serialized_options = b'\372B\n\222\001\007\"\005\202\001\002\020\001'
  _globals['_EXTENSIONFILTER']._loaded_options = None
  _globals['_EXTENSIONFILTER']._serialized_options = b'\232\305\210\0362\n0envoy.config.filter.accesslog.v2.ExtensionFilter'
  _globals['_ACCESSLOG']._serialized_start=410
  _globals['_ACCESSLOG']._serialized_end=621
  _globals['_ACCESSLOGFILTER']._serialized_start=624
  _globals['_ACCESSLOGFILTER']._serialized_end=1641
  _globals['_COMPARISONFILTER']._serialized_start=1644
  _globals['_COMPARISONFILTER']._serialized_end=1882
  _globals['_COMPARISONFILTER_OP']._serialized_start=1796
  _globals['_COMPARISONFILTER_OP']._serialized_end=1824
  _globals['_STATUSCODEFILTER']._serialized_start=1885
  _globals['_STATUSCODEFILTER']._serialized_end=2036
  _globals['_DURATIONFILTER']._serialized_start=2039
  _globals['_DURATIONFILTER']._serialized_end=2186
  _globals['_NOTHEALTHCHECKFILTER']._serialized_start=2188
  _globals['_NOTHEALTHCHECKFILTER']._serialized_end=2272
  _globals['_TRACEABLEFILTER']._serialized_start=2274
  _globals['_TRACEABLEFILTER']._serialized_end=2348
  _globals['_RUNTIMEFILTER']._serialized_start=2351
  _globals['_RUNTIMEFILTER']._serialized_end=2546
  _globals['_ANDFILTER']._serialized_start=2549
  _globals['_ANDFILTER']._serialized_end=2682
  _globals['_ORFILTER']._serialized_start=2685
  _globals['_ORFILTER']._serialized_end=2816
  _globals['_HEADERFILTER']._serialized_start=2819
  _globals['_HEADERFILTER']._serialized_end=2951
  _globals['_RESPONSEFLAGFILTER']._serialized_start=2954
  _globals['_RESPONSEFLAGFILTER']._serialized_end=3197
  _globals['_GRPCSTATUSFILTER']._serialized_start=3200
  _globals['_GRPCSTATUSFILTER']._serialized_end=3693
  _globals['_GRPCSTATUSFILTER_STATUS']._serialized_start=3323
  _globals['_GRPCSTATUSFILTER_STATUS']._serialized_end=3635
  _globals['_METADATAFILTER']._serialized_start=3696
  _globals['_METADATAFILTER']._serialized_end=3885
  _globals['_LOGTYPEFILTER']._serialized_start=3887
  _globals['_LOGTYPEFILTER']._serialized_end=3989
  _globals['_EXTENSIONFILTER']._serialized_start=3992
  _globals['_EXTENSIONFILTER']._serialized_end=4155
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/filters/udp/dns_filter/v3/dns_filter.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/filters/udp/dns_filter/v3/dns_filter.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.core.v3 import resolver_pb2 as envoy_dot_config_dot_core_dot_v3_dot_resolver__pb2
from envoy.data.dns.v3 import dns_table_pb2 as envoy_dot_data_dot_dns_dot_v3_dot_dns__table__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;envoy/extensions/filters/udp/dns_filter/v3/dns_filter.proto\x12*envoy.extensions.filters.udp.dns_filter.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a$envoy/config/core/v3/extension.proto\x1a#envoy/config/core/v3/resolver.proto\x1a!envoy/data/dns/v3/dns_table.proto\x1a\x1egoogle/protobuf/duration.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x93\x06\n\x0f\x44nsFilterConfig\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x66\n\rserver_config\x18\x02 \x01(\x0b\x32O.envoy.extensions.filters.udp.dns_filter.v3.DnsFilterConfig.ServerContextConfig\x12\x66\n\rclient_config\x18\x03 \x01(\x0b\x32O.envoy.extensions.filters.udp.dns_filter.v3.DnsFilterConfig.ClientContextConfig\x1a\xa4\x01\n\x13ServerContextConfig\x12\x37\n\x10inline_dns_table\x18\x01 \x01(\x0b\x32\x1b.envoy.data.dns.v3.DnsTableH\x00\x12>\n\x12\x65xternal_dns_table\x18\x02 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceH\x00\x42\x14\n\rconfig_source\x12\x03\xf8\x42\x01\x1a\xea\x02\n\x13\x43lientContextConfig\x12?\n\x10resolver_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x32\x02\x08\x01\x12\x46\n\x12upstream_resolvers\x18\x02 \x03(\x0b\x32\x1d.envoy.config.core.v3.AddressB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12U\n\x15\x64ns_resolution_config\x18\x05 \x01(\x0b\x32).envoy.config.core.v3.DnsResolutionConfigB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0\x12M\n\x19typed_dns_resolver_config\x18\x04 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x12$\n\x13max_pending_lookups\x18\x03 \x01(\x04\x42\x07\xfa\x42\x04\x32\x02(\x01\x42\xb4\x01\n8io.envoyproxy.envoy.extensions.filters.udp.dns_filter.v3B\x0e\x44nsFilterProtoP\x01Z^github.com/envoyproxy/go-control-plane/envoy/extensions/filters/udp/dns_filter/v3;dns_filterv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.udp.dns_filter.v3.dns_filter_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n8io.envoyproxy.envoy.extensions.filters.udp.dns_filter.v3B\016DnsFilterProtoP\001Z^github.com/envoyproxy/go-control-plane/envoy/extensions/filters/udp/dns_filter/v3;dns_filterv3\272\200\310\321\006\002\020\002'
  _globals['_DNSFILTERCONFIG_SERVERCONTEXTCONFIG'].oneofs_by_name['config_source']._loaded_options = None
  _globals['_DNSFILTERCONFIG_SERVERCONTEXTCONFIG'].oneofs_by_name['config_source']._serialized_options = b'\370B\001'
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG'].fields_by_name['resolver_timeout']._loaded_options = None
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG'].fields_by_name['resolver_timeout']._serialized_options = b'\372B\007\252\001\0042\002\010\001'
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG'].fields_by_name['upstream_resolvers']._loaded_options = None
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG'].fields_by_name['upstream_resolvers']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG'].fields_by_name['dns_resolution_config']._loaded_options = None
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG'].fields_by_name['dns_resolution_config']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG'].fields_by_name['max_pending_lookups']._loaded_options = None
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG'].fields_by_name['max_pending_lookups']._serialized_options = b'\372B\0042\002(\001'
  _globals['_DNSFILTERCONFIG'].fields_by_name['stat_prefix']._loaded_options = None
  _globals['_DNSFILTERCONFIG'].fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DNSFILTERCONFIG']._serialized_start=412
  _globals['_DNSFILTERCONFIG']._serialized_end=1199
  _globals['_DNSFILTERCONFIG_SERVERCONTEXTCONFIG']._serialized_start=670
  _globals['_DNSFILTERCONFIG_SERVERCONTEXTCONFIG']._serialized_end=834
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG']._serialized_start=837
  _globals['_DNSFILTERCONFIG_CLIENTCONTEXTCONFIG']._serialized_end=1199
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/api/expr/v1alpha1/value.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/api/expr/v1alpha1/value.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$google/api/expr/v1alpha1/value.proto\x12\x18google.api.expr.v1alpha1\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xc0\x03\n\x05Value\x12\x30\n\nnull_value\x18\x01 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12\x14\n\nbool_value\x18\x02 \x01(\x08H\x00\x12\x15\n\x0bint64_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0cuint64_value\x18\x04 \x01(\x04H\x00\x12\x16\n\x0c\x64ouble_value\x18\x05 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x06 \x01(\tH\x00\x12\x15\n\x0b\x62ytes_value\x18\x07 \x01(\x0cH\x00\x12\x39\n\nenum_value\x18\t \x01(\x0b\x32#.google.api.expr.v1alpha1.EnumValueH\x00\x12,\n\x0cobject_value\x18\n \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12\x37\n\tmap_value\x18\x0b \x01(\x0b\x32\".google.api.expr.v1alpha1.MapValueH\x00\x12\x39\n\nlist_value\x18\x0c \x01(\x0b\x32#.google.api.expr.v1alpha1.ListValueH\x00\x12\x14\n\ntype_value\x18\x0f \x01(\tH\x00\x42\x06\n\x04kind\"(\n\tEnumValue\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05\"<\n\tListValue\x12/\n\x06values\x18\x01 \x03(\x0b\x32\x1f.google.api.expr.v1alpha1.Value\"\xac\x01\n\x08MapValue\x12\x39\n\x07\x65ntries\x18\x01 \x03(\x0b\x32(.google.api.expr.v1alpha1.MapValue.Entry\x1a\x65\n\x05\x45ntry\x12,\n\x03key\x18\x01 \x01(\x0b\x32\x1f.google.api.expr.v1alpha1.Value\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.google.api.expr.v1alpha1.ValueBm\n\x1c\x63om.google.api.expr.v1alpha1B\nValueProtoP\x01Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.api.expr.v1alpha1.value_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.google.api.expr.v1alpha1B\nValueProtoP\001Z<google.golang.org/genproto/googleapis/api/expr/v1alpha1;expr\370\001\001'
  _globals['_VALUE']._serialized_start=124
  _globals['_VALUE']._serialized_end=572
  _globals['_ENUMVALUE']._serialized_start=574
  _globals['_ENUMVALUE']._serialized_end=614
  _globals['_LISTVALUE']._serialized_start=616
  _globals['_LISTVALUE']._serialized_end=676
  _globals['_MAPVALUE']._serialized_start=679
  _globals['_MAPVALUE']._serialized_end=851
  _globals['_MAPVALUE_ENTRY']._serialized_start=750
  _globals['_MAPVALUE_ENTRY']._serialized_end=851
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/listener/v3/udp_listener_config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/listener/v3/udp_listener_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.core.v3 import udp_socket_config_pb2 as envoy_dot_config_dot_core_dot_v3_dot_udp__socket__config__pb2
from envoy.config.listener.v3 import quic_config_pb2 as envoy_dot_config_dot_listener_dot_v3_dot_quic__config__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2envoy/config/listener/v3/udp_listener_config.proto\x12\x18\x65nvoy.config.listener.v3\x1a$envoy/config/core/v3/extension.proto\x1a,envoy/config/core/v3/udp_socket_config.proto\x1a*envoy/config/listener/v3/quic_config.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xcc\x02\n\x11UdpListenerConfig\x12G\n\x18\x64ownstream_socket_config\x18\x05 \x01(\x0b\x32%.envoy.config.core.v3.UdpSocketConfig\x12\x43\n\x0cquic_options\x18\x07 \x01(\x0b\x32-.envoy.config.listener.v3.QuicProtocolOptions\x12S\n\x1fudp_packet_packet_writer_config\x18\x08 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig:.\x9a\xc5\x88\x1e)\n\'envoy.api.v2.listener.UdpListenerConfigJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x06\x10\x07R\x06\x63onfig\"U\n\x1a\x41\x63tiveRawUdpListenerConfig:7\x9a\xc5\x88\x1e\x32\n0envoy.api.v2.listener.ActiveRawUdpListenerConfigB\x96\x01\n&io.envoyproxy.envoy.config.listener.v3B\x16UdpListenerConfigProtoP\x01ZJgithub.com/envoyproxy/go-control-plane/envoy/config/listener/v3;listenerv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.listener.v3.udp_listener_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&io.envoyproxy.envoy.config.listener.v3B\026UdpListenerConfigProtoP\001ZJgithub.com/envoyproxy/go-control-plane/envoy/config/listener/v3;listenerv3\272\200\310\321\006\002\020\002'
  _globals['_UDPLISTENERCONFIG']._loaded_options = None
  _globals['_UDPLISTENERCONFIG']._serialized_options = b'\232\305\210\036)\n\'envoy.api.v2.listener.UdpListenerConfig'
  _globals['_ACTIVERAWUDPLISTENERCONFIG']._loaded_options = None
  _globals['_ACTIVERAWUDPLISTENERCONFIG']._serialized_options = b'\232\305\210\0362\n0envoy.api.v2.listener.ActiveRawUdpListenerConfig'
  _globals['_UDPLISTENERCONFIG']._serialized_start=275
  _globals['_UDPLISTENERCONFIG']._serialized_end=607
  _globals['_ACTIVERAWUDPLISTENERCONFIG']._serialized_start=609
  _globals['_ACTIVERAWUDPLISTENERCONFIG']._serialized_end=694
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/filter/http/squash/v2/squash.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/filter/http/squash/v2/squash.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/envoy/config/filter/http/squash/v2/squash.proto\x12\"envoy.config.filter.http.squash.v2\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xfe\x01\n\x06Squash\x12\x18\n\x07\x63luster\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x34\n\x13\x61ttachment_template\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x32\n\x0frequest_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\x12\x61ttachment_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x39\n\x16\x61ttachment_poll_period\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\xcc\x01\n0io.envoyproxy.envoy.config.filter.http.squash.v2B\x0bSquashProtoP\x01ZRgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/squash/v2;squashv2\xf2\x98\xfe\x8f\x05)\x12\'envoy.extensions.filters.http.squash.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.squash.v2.squash_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0io.envoyproxy.envoy.config.filter.http.squash.v2B\013SquashProtoP\001ZRgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/squash/v2;squashv2\362\230\376\217\005)\022\'envoy.extensions.filters.http.squash.v3\272\200\310\321\006\002\020\001'
  _globals['_SQUASH'].fields_by_name['cluster']._loaded_options = None
  _globals['_SQUASH'].fields_by_name['cluster']._serialized_options = b'\372B\004r\002 \001'
  _globals['_SQUASH']._serialized_start=238
  _globals['_SQUASH']._serialized_end=492
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/filter/network/zookeeper_proxy/v1alpha1/zookeeper_proxy.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/filter/network/zookeeper_proxy/v1alpha1/zookeeper_proxy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJenvoy/config/filter/network/zookeeper_proxy/v1alpha1/zookeeper_proxy.proto\x12\x34\x65nvoy.config.filter.network.zookeeper_proxy.v1alpha1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"z\n\x0eZooKeeperProxy\x12\x1c\n\x0bstat_prefix\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x12\n\naccess_log\x18\x02 \x01(\t\x12\x36\n\x10max_packet_bytes\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\xfb\x01\nBio.envoyproxy.envoy.config.filter.network.zookeeper_proxy.v1alpha1B\x13ZookeeperProxyProtoP\x01Z[github.com/envoyproxy/go-control-plane/envoy/config/filter/network/zookeeper_proxy/v1alpha1\xf2\x98\xfe\x8f\x05\x35\x12\x33\x65nvoy.extensions.filters.network.zookeeper_proxy.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.network.zookeeper_proxy.v1alpha1.zookeeper_proxy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nBio.envoyproxy.envoy.config.filter.network.zookeeper_proxy.v1alpha1B\023ZookeeperProxyProtoP\001Z[github.com/envoyproxy/go-control-plane/envoy/config/filter/network/zookeeper_proxy/v1alpha1\362\230\376\217\0055\0223envoy.extensions.filters.network.zookeeper_proxy.v3\272\200\310\321\006\002\020\001'
  _globals['_ZOOKEEPERPROXY'].fields_by_name['stat_prefix']._loaded_options = None
  _globals['_ZOOKEEPERPROXY'].fields_by_name['stat_prefix']._serialized_options = b'\372B\004r\002 \001'
  _globals['_ZOOKEEPERPROXY']._serialized_start=252
  _globals['_ZOOKEEPERPROXY']._serialized_end=374
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/service/route/v3/srds.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/service/route/v3/srds.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!envoy/service/route/v3/srds.proto\x12\x16\x65nvoy.service.route.v3\x1a*envoy/service/discovery/v3/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"*\n\tSrdsDummy:\x1d\x9a\xc5\x88\x1e\x18\n\x16\x65nvoy.api.v2.SrdsDummy2\xed\x03\n\x1cScopedRoutesDiscoveryService\x12w\n\x12StreamScopedRoutes\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\x00(\x01\x30\x01\x12\x80\x01\n\x11\x44\x65ltaScopedRoutes\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12\x98\x01\n\x11\x46\x65tchScopedRoutes\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"&\x82\xd3\xe4\x93\x02 \"\x1b/v3/discovery:scoped-routes:\x01*\x1a\x36\x8a\xa4\x96\xf3\x07\x30\n.envoy.config.route.v3.ScopedRouteConfigurationB\x82\x01\n$io.envoyproxy.envoy.service.route.v3B\tSrdsProtoP\x01ZEgithub.com/envoyproxy/go-control-plane/envoy/service/route/v3;routev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.route.v3.srds_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$io.envoyproxy.envoy.service.route.v3B\tSrdsProtoP\001ZEgithub.com/envoyproxy/go-control-plane/envoy/service/route/v3;routev3\272\200\310\321\006\002\020\002'
  _globals['_SRDSDUMMY']._loaded_options = None
  _globals['_SRDSDUMMY']._serialized_options = b'\232\305\210\036\030\n\026envoy.api.v2.SrdsDummy'
  _globals['_SCOPEDROUTESDISCOVERYSERVICE']._loaded_options = None
  _globals['_SCOPEDROUTESDISCOVERYSERVICE']._serialized_options = b'\212\244\226\363\0070\n.envoy.config.route.v3.ScopedRouteConfiguration'
  _globals['_SCOPEDROUTESDISCOVERYSERVICE'].methods_by_name['FetchScopedRoutes']._loaded_options = None
  _globals['_SCOPEDROUTESDISCOVERYSERVICE'].methods_by_name['FetchScopedRoutes']._serialized_options = b'\202\323\344\223\002 \"\033/v3/discovery:scoped-routes:\001*'
  _globals['_SRDSDUMMY']._serialized_start=235
  _globals['_SRDSDUMMY']._serialized_end=277
  _globals['_SCOPEDROUTESDISCOVERYSERVICE']._serialized_start=280
  _globals['_SCOPEDROUTESDISCOVERYSERVICE']._serialized_end=773
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/tracers/opentelemetry/resource_detectors/v3/static_config_resource_detector.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/tracers/opentelemetry/resource_detectors/v3/static_config_resource_detector.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nbenvoy/extensions/tracers/opentelemetry/resource_detectors/v3/static_config_resource_detector.proto\x12<envoy.extensions.tracers.opentelemetry.resource_detectors.v3\x1a\x1dudpa/annotations/status.proto\"\xde\x01\n\"StaticConfigResourceDetectorConfig\x12\x84\x01\n\nattributes\x18\x01 \x03(\x0b\x32p.envoy.extensions.tracers.opentelemetry.resource_detectors.v3.StaticConfigResourceDetectorConfig.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\xf3\x01\nJio.envoyproxy.envoy.extensions.tracers.opentelemetry.resource_detectors.v3B!StaticConfigResourceDetectorProtoP\x01Zxgithub.com/envoyproxy/go-control-plane/envoy/extensions/tracers/opentelemetry/resource_detectors/v3;resource_detectorsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.tracers.opentelemetry.resource_detectors.v3.static_config_resource_detector_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nJio.envoyproxy.envoy.extensions.tracers.opentelemetry.resource_detectors.v3B!StaticConfigResourceDetectorProtoP\001Zxgithub.com/envoyproxy/go-control-plane/envoy/extensions/tracers/opentelemetry/resource_detectors/v3;resource_detectorsv3\272\200\310\321\006\002\020\002'
  _globals['_STATICCONFIGRESOURCEDETECTORCONFIG_ATTRIBUTESENTRY']._loaded_options = None
  _globals['_STATICCONFIGRESOURCEDETECTORCONFIG_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_STATICCONFIGRESOURCEDETECTORCONFIG']._serialized_start=196
  _globals['_STATICCONFIGRESOURCEDETECTORCONFIG']._serialized_end=418
  _globals['_STATICCONFIGRESOURCEDETECTORCONFIG_ATTRIBUTESENTRY']._serialized_start=369
  _globals['_STATICCONFIGRESOURCEDETECTORCONFIG_ATTRIBUTESENTRY']._serialized_end=418
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/filter/http/csrf/v2/csrf.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/filter/http/csrf/v2/csrf.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+envoy/config/filter/http/csrf/v2/csrf.proto\x12 envoy.config.filter.http.csrf.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xdf\x01\n\nCsrfPolicy\x12M\n\x0e\x66ilter_enabled\x18\x01 \x01(\x0b\x32+.envoy.api.v2.core.RuntimeFractionalPercentB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x43\n\x0eshadow_enabled\x18\x02 \x01(\x0b\x32+.envoy.api.v2.core.RuntimeFractionalPercent\x12=\n\x12\x61\x64\x64itional_origins\x18\x03 \x03(\x0b\x32!.envoy.type.matcher.StringMatcherB\xc2\x01\n.io.envoyproxy.envoy.config.filter.http.csrf.v2B\tCsrfProtoP\x01ZNgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/csrf/v2;csrfv2\xf2\x98\xfe\x8f\x05\'\x12%envoy.extensions.filters.http.csrf.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.filter.http.csrf.v2.csrf_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n.io.envoyproxy.envoy.config.filter.http.csrf.v2B\tCsrfProtoP\001ZNgithub.com/envoyproxy/go-control-plane/envoy/config/filter/http/csrf/v2;csrfv2\362\230\376\217\005\'\022%envoy.extensions.filters.http.csrf.v3\272\200\310\321\006\002\020\001'
  _globals['_CSRFPOLICY'].fields_by_name['filter_enabled']._loaded_options = None
  _globals['_CSRFPOLICY'].fields_by_name['filter_enabled']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_CSRFPOLICY']._serialized_start=233
  _globals['_CSRFPOLICY']._serialized_end=456
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/transport_sockets/alts/v3/alts.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/transport_sockets/alts/v3/alts.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5envoy/extensions/transport_sockets/alts/v3/alts.proto\x12*envoy.extensions.transport_sockets.alts.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x82\x01\n\x04\x41lts\x12#\n\x12handshaker_service\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1d\n\x15peer_service_accounts\x18\x02 \x03(\t:6\x9a\xc5\x88\x1e\x31\n/envoy.config.transport_socket.alts.v2alpha.AltsB\xa9\x01\n8io.envoyproxy.envoy.extensions.transport_sockets.alts.v3B\tAltsProtoP\x01ZXgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/alts/v3;altsv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.transport_sockets.alts.v3.alts_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n8io.envoyproxy.envoy.extensions.transport_sockets.alts.v3B\tAltsProtoP\001ZXgithub.com/envoyproxy/go-control-plane/envoy/extensions/transport_sockets/alts/v3;altsv3\272\200\310\321\006\002\020\002'
  _globals['_ALTS'].fields_by_name['handshaker_service']._loaded_options = None
  _globals['_ALTS'].fields_by_name['handshaker_service']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_ALTS']._loaded_options = None
  _globals['_ALTS']._serialized_options = b'\232\305\210\0361\n/envoy.config.transport_socket.alts.v2alpha.Alts'
  _globals['_ALTS']._serialized_start=193
  _globals['_ALTS']._serialized_end=323
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/trace/v3/xray.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/trace/v3/xray.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n envoy/config/trace/v3/xray.proto\x12\x15\x65nvoy.config.trace.v3\x1a\"envoy/config/core/v3/address.proto\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xe9\x02\n\nXRayConfig\x12<\n\x0f\x64\x61\x65mon_endpoint\x18\x01 \x01(\x0b\x32#.envoy.config.core.v3.SocketAddress\x12\x1d\n\x0csegment_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12@\n\x16sampling_rule_manifest\x18\x03 \x01(\x0b\x32 .envoy.config.core.v3.DataSource\x12G\n\x0esegment_fields\x18\x04 \x01(\x0b\x32/.envoy.config.trace.v3.XRayConfig.SegmentFields\x1a\x45\n\rSegmentFields\x12\x0e\n\x06origin\x18\x01 \x01(\t\x12$\n\x03\x61ws\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct:,\x9a\xc5\x88\x1e\'\n%envoy.config.trace.v2alpha.XRayConfigB\xad\x01\n#io.envoyproxy.envoy.config.trace.v3B\tXrayProtoP\x01ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\xf2\x98\xfe\x8f\x05\'\x12%envoy.extensions.tracers.xray.v4alpha\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.trace.v3.xray_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#io.envoyproxy.envoy.config.trace.v3B\tXrayProtoP\001ZDgithub.com/envoyproxy/go-control-plane/envoy/config/trace/v3;tracev3\362\230\376\217\005\'\022%envoy.extensions.tracers.xray.v4alpha\272\200\310\321\006\002\020\002'
  _globals['_XRAYCONFIG'].fields_by_name['segment_name']._loaded_options = None
  _globals['_XRAYCONFIG'].fields_by_name['segment_name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_XRAYCONFIG']._loaded_options = None
  _globals['_XRAYCONFIG']._serialized_options = b'\232\305\210\036\'\n%envoy.config.trace.v2alpha.XRayConfig'
  _globals['_XRAYCONFIG']._serialized_start=282
  _globals['_XRAYCONFIG']._serialized_end=643
  _globals['_XRAYCONFIG_SEGMENTFIELDS']._serialized_start=528
  _globals['_XRAYCONFIG_SEGMENTFIELDS']._serialized_end=597
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/http/custom_response/redirect_policy/v3/redirect_policy.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/http/custom_response/redirect_policy/v3/redirect_policy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.route.v3 import route_components_pb2 as envoy_dot_config_dot_route_dot_v3_dot_route__components__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNenvoy/extensions/http/custom_response/redirect_policy/v3/redirect_policy.proto\x12\x38\x65nvoy.extensions.http.custom_response.redirect_policy.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a$envoy/config/core/v3/extension.proto\x1a,envoy/config/route/v3/route_components.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc8\x03\n\x0eRedirectPolicy\x12\x16\n\x03uri\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12@\n\x0fredirect_action\x18\x02 \x01(\x0b\x32%.envoy.config.route.v3.RedirectActionH\x00\x12>\n\x0bstatus_code\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0b\xfa\x42\x08*\x06\x18\xe7\x07(\xc8\x01\x12S\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12R\n\x16request_headers_to_add\x18\x05 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12Q\n\x1dmodify_request_headers_action\x18\x06 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfigB \n\x19redirect_action_specifier\x12\x03\xf8\x42\x01\x42\xe2\x01\nFio.envoyproxy.envoy.extensions.http.custom_response.redirect_policy.v3B\x13RedirectPolicyProtoP\x01Zqgithub.com/envoyproxy/go-control-plane/envoy/extensions/http/custom_response/redirect_policy/v3;redirect_policyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.http.custom_response.redirect_policy.v3.redirect_policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\nFio.envoyproxy.envoy.extensions.http.custom_response.redirect_policy.v3B\023RedirectPolicyProtoP\001Zqgithub.com/envoyproxy/go-control-plane/envoy/extensions/http/custom_response/redirect_policy/v3;redirect_policyv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _globals['_REDIRECTPOLICY'].oneofs_by_name['redirect_action_specifier']._loaded_options = None
  _globals['_REDIRECTPOLICY'].oneofs_by_name['redirect_action_specifier']._serialized_options = b'\370B\001'
  _globals['_REDIRECTPOLICY'].fields_by_name['uri']._loaded_options = None
  _globals['_REDIRECTPOLICY'].fields_by_name['uri']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_REDIRECTPOLICY'].fields_by_name['status_code']._loaded_options = None
  _globals['_REDIRECTPOLICY'].fields_by_name['status_code']._serialized_options = b'\372B\010*\006\030\347\007(\310\001'
  _globals['_REDIRECTPOLICY'].fields_by_name['response_headers_to_add']._loaded_options = None
  _globals['_REDIRECTPOLICY'].fields_by_name['response_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _globals['_REDIRECTPOLICY'].fields_by_name['request_headers_to_add']._loaded_options = None
  _globals['_REDIRECTPOLICY'].fields_by_name['request_headers_to_add']._serialized_options = b'\372B\006\222\001\003\020\350\007'
  _globals['_REDIRECTPOLICY']._serialized_start=379
  _globals['_REDIRECTPOLICY']._serialized_end=835
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/trace/v2/trace_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from opencensus.proto.trace.v1 import trace_pb2 as opencensus_dot_proto_dot_trace_dot_v1_dot_trace__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*envoy/service/trace/v2/trace_service.proto\x12\x16\x65nvoy.service.trace.v2\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a%opencensus/proto/trace/v1/trace.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x16\n\x14StreamTracesResponse\"\xd0\x01\n\x13StreamTracesMessage\x12J\n\nidentifier\x18\x01 \x01(\x0b\x32\x36.envoy.service.trace.v2.StreamTracesMessage.Identifier\x12.\n\x05spans\x18\x02 \x03(\x0b\x32\x1f.opencensus.proto.trace.v1.Span\x1a=\n\nIdentifier\x12/\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.NodeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x32}\n\x0cTraceService\x12m\n\x0cStreamTraces\x12+.envoy.service.trace.v2.StreamTracesMessage\x1a,.envoy.service.trace.v2.StreamTracesResponse\"\x00(\x01\x42\x8a\x01\n$io.envoyproxy.envoy.service.trace.v2B\x11TraceServiceProtoP\x01ZEgithub.com/envoyproxy/go-control-plane/envoy/service/trace/v2;tracev2\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.trace.v2.trace_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.envoyproxy.envoy.service.trace.v2B\021TraceServiceProtoP\001ZEgithub.com/envoyproxy/go-control-plane/envoy/service/trace/v2;tracev2\272\200\310\321\006\002\020\001'
  _STREAMTRACESMESSAGE_IDENTIFIER.fields_by_name['node']._options = None
  _STREAMTRACESMESSAGE_IDENTIFIER.fields_by_name['node']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_STREAMTRACESRESPONSE']._serialized_start=195
  _globals['_STREAMTRACESRESPONSE']._serialized_end=217
  _globals['_STREAMTRACESMESSAGE']._serialized_start=220
  _globals['_STREAMTRACESMESSAGE']._serialized_end=428
  _globals['_STREAMTRACESMESSAGE_IDENTIFIER']._serialized_start=367
  _globals['_STREAMTRACESMESSAGE_IDENTIFIER']._serialized_end=428
  _globals['_TRACESERVICE']._serialized_start=430
  _globals['_TRACESERVICE']._serialized_end=555
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/service/tap/v2alpha/tap.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/service/tap/v2alpha/tap.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.data.tap.v2alpha import wrapper_pb2 as envoy_dot_data_dot_tap_dot_v2alpha_dot_wrapper__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#envoy/service/tap/v2alpha/tap.proto\x12\x19\x65nvoy.service.tap.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a$envoy/data/tap/v2alpha/wrapper.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xf6\x01\n\x11StreamTapsRequest\x12K\n\nidentifier\x18\x01 \x01(\x0b\x32\x37.envoy.service.tap.v2alpha.StreamTapsRequest.Identifier\x12\x10\n\x08trace_id\x18\x02 \x01(\x04\x12\x33\n\x05trace\x18\x03 \x01(\x0b\x32$.envoy.data.tap.v2alpha.TraceWrapper\x1aM\n\nIdentifier\x12/\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.NodeB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x0e\n\x06tap_id\x18\x02 \x01(\t\"\x14\n\x12StreamTapsResponse2\x7f\n\x0eTapSinkService\x12m\n\nStreamTaps\x12,.envoy.service.tap.v2alpha.StreamTapsRequest\x1a-.envoy.service.tap.v2alpha.StreamTapsResponse\"\x00(\x01\x42\x7f\n\'io.envoyproxy.envoy.service.tap.v2alphaB\x08TapProtoP\x01Z@github.com/envoyproxy/go-control-plane/envoy/service/tap/v2alpha\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.service.tap.v2alpha.tap_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'io.envoyproxy.envoy.service.tap.v2alphaB\010TapProtoP\001Z@github.com/envoyproxy/go-control-plane/envoy/service/tap/v2alpha\272\200\310\321\006\002\020\001'
  _globals['_STREAMTAPSREQUEST_IDENTIFIER'].fields_by_name['node']._loaded_options = None
  _globals['_STREAMTAPSREQUEST_IDENTIFIER'].fields_by_name['node']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_STREAMTAPSREQUEST']._serialized_start=191
  _globals['_STREAMTAPSREQUEST']._serialized_end=437
  _globals['_STREAMTAPSREQUEST_IDENTIFIER']._serialized_start=360
  _globals['_STREAMTAPSREQUEST_IDENTIFIER']._serialized_end=437
  _globals['_STREAMTAPSRESPONSE']._serialized_start=439
  _globals['_STREAMTAPSRESPONSE']._serialized_end=459
  _globals['_TAPSINKSERVICE']._serialized_start=461
  _globals['_TAPSINKSERVICE']._serialized_end=588
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/clusters/dynamic_forward_proxy/v3/cluster.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/clusters/dynamic_forward_proxy/v3/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.cluster.v3 import cluster_pb2 as envoy_dot_config_dot_cluster_dot_v3_dot_cluster__pb2
from envoy.config.core.v3 import address_pb2 as envoy_dot_config_dot_core_dot_v3_dot_address__pb2
from envoy.extensions.common.dynamic_forward_proxy.v3 import dns_cache_pb2 as envoy_dot_extensions_dot_common_dot_dynamic__forward__proxy_dot_v3_dot_dns__cache__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@envoy/extensions/clusters/dynamic_forward_proxy/v3/cluster.proto\x12\x32\x65nvoy.extensions.clusters.dynamic_forward_proxy.v3\x1a%envoy/config/cluster/v3/cluster.proto\x1a\"envoy/config/core/v3/address.proto\x1a@envoy/extensions/common/dynamic_forward_proxy/v3/dns_cache.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x8d\x03\n\rClusterConfig\x12\\\n\x10\x64ns_cache_config\x18\x01 \x01(\x0b\x32@.envoy.extensions.common.dynamic_forward_proxy.v3.DnsCacheConfigH\x00\x12\x64\n\x13sub_clusters_config\x18\x04 \x01(\x0b\x32\x45.envoy.extensions.clusters.dynamic_forward_proxy.v3.SubClustersConfigH\x00\x12&\n\x1e\x61llow_insecure_cluster_options\x18\x02 \x01(\x08\x12#\n\x1b\x61llow_coalesced_connections\x18\x03 \x01(\x08:G\x9a\xc5\x88\x1e\x42\n@envoy.config.cluster.dynamic_forward_proxy.v2alpha.ClusterConfigB\"\n cluster_implementation_specifier\"\x9c\x02\n\x11SubClustersConfig\x12\x46\n\tlb_policy\x18\x01 \x01(\x0e\x32).envoy.config.cluster.v3.Cluster.LbPolicyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12?\n\x10max_sub_clusters\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12<\n\x0fsub_cluster_ttl\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12@\n\x13preresolve_clusters\x18\x04 \x03(\x0b\x32#.envoy.config.core.v3.SocketAddressB\xcd\x01\n@io.envoyproxy.envoy.extensions.clusters.dynamic_forward_proxy.v3B\x0c\x43lusterProtoP\x01Zqgithub.com/envoyproxy/go-control-plane/envoy/extensions/clusters/dynamic_forward_proxy/v3;dynamic_forward_proxyv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.clusters.dynamic_forward_proxy.v3.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n@io.envoyproxy.envoy.extensions.clusters.dynamic_forward_proxy.v3B\014ClusterProtoP\001Zqgithub.com/envoyproxy/go-control-plane/envoy/extensions/clusters/dynamic_forward_proxy/v3;dynamic_forward_proxyv3\272\200\310\321\006\002\020\002'
  _globals['_CLUSTERCONFIG']._loaded_options = None
  _globals['_CLUSTERCONFIG']._serialized_options = b'\232\305\210\036B\n@envoy.config.cluster.dynamic_forward_proxy.v2alpha.ClusterConfig'
  _globals['_SUBCLUSTERSCONFIG'].fields_by_name['lb_policy']._loaded_options = None
  _globals['_SUBCLUSTERSCONFIG'].fields_by_name['lb_policy']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_SUBCLUSTERSCONFIG'].fields_by_name['max_sub_clusters']._loaded_options = None
  _globals['_SUBCLUSTERSCONFIG'].fields_by_name['max_sub_clusters']._serialized_options = b'\372B\004*\002 \000'
  _globals['_SUBCLUSTERSCONFIG'].fields_by_name['sub_cluster_ttl']._loaded_options = None
  _globals['_SUBCLUSTERSCONFIG'].fields_by_name['sub_cluster_ttl']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_CLUSTERCONFIG']._serialized_start=417
  _globals['_CLUSTERCONFIG']._serialized_end=814
  _globals['_SUBCLUSTERSCONFIG']._serialized_start=817
  _globals['_SUBCLUSTERSCONFIG']._serialized_end=1101
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/config/core/v3/config_source.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/config/core/v3/config_source.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.core.v3 import grpc_service_pb2 as envoy_dot_config_dot_core_dot_v3_dot_grpc__service__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.core.v3 import authority_pb2 as xds_dot_core_dot_v3_dot_authority__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(envoy/config/core/v3/config_source.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a$envoy/config/core/v3/extension.proto\x1a\'envoy/config/core/v3/grpc_service.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bxds/core/v3/authority.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xdc\x05\n\x0f\x41piConfigSource\x12I\n\x08\x61pi_type\x18\x01 \x01(\x0e\x32-.envoy.config.core.v3.ApiConfigSource.ApiTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12I\n\x15transport_api_version\x18\x08 \x01(\x0e\x32 .envoy.config.core.v3.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rcluster_names\x18\x02 \x03(\t\x12\x38\n\rgrpc_services\x18\x04 \x03(\x0b\x32!.envoy.config.core.v3.GrpcService\x12\x30\n\rrefresh_delay\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12<\n\x0frequest_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x44\n\x13rate_limit_settings\x18\x06 \x01(\x0b\x32\'.envoy.config.core.v3.RateLimitSettings\x12&\n\x1eset_node_on_first_message_only\x18\x07 \x01(\x08\x12\x45\n\x11\x63onfig_validators\x18\t \x03(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\"\x92\x01\n\x07\x41piType\x12\x33\n%DEPRECATED_AND_UNAVAILABLE_DO_NOT_USE\x10\x00\x1a\x08\x08\x01\xa8\xf7\xb4\x8b\x02\x01\x12\x08\n\x04REST\x10\x01\x12\x08\n\x04GRPC\x10\x02\x12\x0e\n\nDELTA_GRPC\x10\x03\x12\x13\n\x0f\x41GGREGATED_GRPC\x10\x05\x12\x19\n\x15\x41GGREGATED_DELTA_GRPC\x10\x06:(\x9a\xc5\x88\x1e#\n!envoy.api.v2.core.ApiConfigSource\"I\n\x16\x41ggregatedConfigSource:/\x9a\xc5\x88\x1e*\n(envoy.api.v2.core.AggregatedConfigSource\"\x88\x01\n\x10SelfConfigSource\x12I\n\x15transport_api_version\x18\x01 \x01(\x0e\x32 .envoy.config.core.v3.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:)\x9a\xc5\x88\x1e$\n\"envoy.api.v2.core.SelfConfigSource\"\xb2\x01\n\x11RateLimitSettings\x12\x30\n\nmax_tokens\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12?\n\tfill_rate\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueB\x0e\xfa\x42\x0b\x12\t!\x00\x00\x00\x00\x00\x00\x00\x00:*\x9a\xc5\x88\x1e%\n#envoy.api.v2.core.RateLimitSettings\"l\n\x10PathConfigSource\x12\x15\n\x04path\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x41\n\x11watched_directory\x18\x02 \x01(\x0b\x32&.envoy.config.core.v3.WatchedDirectory\"\xa2\x04\n\x0c\x43onfigSource\x12+\n\x0b\x61uthorities\x18\x07 \x03(\x0b\x32\x16.xds.core.v3.Authority\x12\x1b\n\x04path\x18\x01 \x01(\tB\x0b\x18\x01\x92\xc7\x86\xd8\x04\x03\x33.0H\x00\x12\x44\n\x12path_config_source\x18\x08 \x01(\x0b\x32&.envoy.config.core.v3.PathConfigSourceH\x00\x12\x42\n\x11\x61pi_config_source\x18\x02 \x01(\x0b\x32%.envoy.config.core.v3.ApiConfigSourceH\x00\x12;\n\x03\x61\x64s\x18\x03 \x01(\x0b\x32,.envoy.config.core.v3.AggregatedConfigSourceH\x00\x12\x36\n\x04self\x18\x05 \x01(\x0b\x32&.envoy.config.core.v3.SelfConfigSourceH\x00\x12\x38\n\x15initial_fetch_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12H\n\x14resource_api_version\x18\x06 \x01(\x0e\x32 .envoy.config.core.v3.ApiVersionB\x08\xfa\x42\x05\x82\x01\x02\x10\x01:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.api.v2.core.ConfigSourceB\x1e\n\x17\x63onfig_source_specifier\x12\x03\xf8\x42\x01\"\xd5\x01\n\x15\x45xtensionConfigSource\x12\x43\n\rconfig_source\x18\x01 \x01(\x0b\x32\".envoy.config.core.v3.ConfigSourceB\x08\xfa\x42\x05\xa2\x01\x02\x08\x01\x12,\n\x0e\x64\x65\x66\x61ult_config\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12,\n$apply_default_config_without_warming\x18\x03 \x01(\x08\x12\x1b\n\ttype_urls\x18\x04 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01*3\n\nApiVersion\x12\x08\n\x04\x41UTO\x10\x00\x12\x13\n\x02V2\x10\x01\x1a\x0b\x08\x01\x8a\xf4\x9b\xb3\x05\x03\x33.0\x12\x06\n\x02V3\x10\x02\x42\x85\x01\n\"io.envoyproxy.envoy.config.core.v3B\x11\x43onfigSourceProtoP\x01ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.config.core.v3.config_source_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"io.envoyproxy.envoy.config.core.v3B\021ConfigSourceProtoP\001ZBgithub.com/envoyproxy/go-control-plane/envoy/config/core/v3;corev3\272\200\310\321\006\002\020\002'
  _globals['_APIVERSION'].values_by_name["V2"]._loaded_options = None
  _globals['_APIVERSION'].values_by_name["V2"]._serialized_options = b'\010\001\212\364\233\263\005\0033.0'
  _globals['_APICONFIGSOURCE_APITYPE'].values_by_name["DEPRECATED_AND_UNAVAILABLE_DO_NOT_USE"]._loaded_options = None
  _globals['_APICONFIGSOURCE_APITYPE'].values_by_name["DEPRECATED_AND_UNAVAILABLE_DO_NOT_USE"]._serialized_options = b'\010\001\250\367\264\213\002\001'
  _globals['_APICONFIGSOURCE'].fields_by_name['api_type']._loaded_options = None
  _globals['_APICONFIGSOURCE'].fields_by_name['api_type']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_APICONFIGSOURCE'].fields_by_name['transport_api_version']._loaded_options = None
  _globals['_APICONFIGSOURCE'].fields_by_name['transport_api_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_APICONFIGSOURCE'].fields_by_name['request_timeout']._loaded_options = None
  _globals['_APICONFIGSOURCE'].fields_by_name['request_timeout']._serialized_options = b'\372B\005\252\001\002*\000'
  _globals['_APICONFIGSOURCE']._loaded_options = None
  _globals['_APICONFIGSOURCE']._serialized_options = b'\232\305\210\036#\n!envoy.api.v2.core.ApiConfigSource'
  _globals['_AGGREGATEDCONFIGSOURCE']._loaded_options = None
  _globals['_AGGREGATEDCONFIGSOURCE']._serialized_options = b'\232\305\210\036*\n(envoy.api.v2.core.AggregatedConfigSource'
  _globals['_SELFCONFIGSOURCE'].fields_by_name['transport_api_version']._loaded_options = None
  _globals['_SELFCONFIGSOURCE'].fields_by_name['transport_api_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_SELFCONFIGSOURCE']._loaded_options = None
  _globals['_SELFCONFIGSOURCE']._serialized_options = b'\232\305\210\036$\n\"envoy.api.v2.core.SelfConfigSource'
  _globals['_RATELIMITSETTINGS'].fields_by_name['fill_rate']._loaded_options = None
  _globals['_RATELIMITSETTINGS'].fields_by_name['fill_rate']._serialized_options = b'\372B\013\022\t!\000\000\000\000\000\000\000\000'
  _globals['_RATELIMITSETTINGS']._loaded_options = None
  _globals['_RATELIMITSETTINGS']._serialized_options = b'\232\305\210\036%\n#envoy.api.v2.core.RateLimitSettings'
  _globals['_PATHCONFIGSOURCE'].fields_by_name['path']._loaded_options = None
  _globals['_PATHCONFIGSOURCE'].fields_by_name['path']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CONFIGSOURCE'].oneofs_by_name['config_source_specifier']._loaded_options = None
  _globals['_CONFIGSOURCE'].oneofs_by_name['config_source_specifier']._serialized_options = b'\370B\001'
  _globals['_CONFIGSOURCE'].fields_by_name['path']._loaded_options = None
  _globals['_CONFIGSOURCE'].fields_by_name['path']._serialized_options = b'\030\001\222\307\206\330\004\0033.0'
  _globals['_CONFIGSOURCE'].fields_by_name['resource_api_version']._loaded_options = None
  _globals['_CONFIGSOURCE'].fields_by_name['resource_api_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_CONFIGSOURCE']._loaded_options = None
  _globals['_CONFIGSOURCE']._serialized_options = b'\232\305\210\036 \n\036envoy.api.v2.core.ConfigSource'
  _globals['_EXTENSIONCONFIGSOURCE'].fields_by_name['config_source']._loaded_options = None
  _globals['_EXTENSIONCONFIGSOURCE'].fields_by_name['config_source']._serialized_options = b'\372B\005\242\001\002\010\001'
  _globals['_EXTENSIONCONFIGSOURCE'].fields_by_name['type_urls']._loaded_options = None
  _globals['_EXTENSIONCONFIGSOURCE'].fields_by_name['type_urls']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_APIVERSION']._serialized_start=2431
  _globals['_APIVERSION']._serialized_end=2482
  _globals['_APICONFIGSOURCE']._serialized_start=427
  _globals['_APICONFIGSOURCE']._serialized_end=1159
  _globals['_APICONFIGSOURCE_APITYPE']._serialized_start=971
  _globals['_APICONFIGSOURCE_APITYPE']._serialized_end=1117
  _globals['_AGGREGATEDCONFIGSOURCE']._serialized_start=1161
  _globals['_AGGREGATEDCONFIGSOURCE']._serialized_end=1234
  _globals['_SELFCONFIGSOURCE']._serialized_start=1237
  _globals['_SELFCONFIGSOURCE']._serialized_end=1373
  _globals['_RATELIMITSETTINGS']._serialized_start=1376
  _globals['_RATELIMITSETTINGS']._serialized_end=1554
  _globals['_PATHCONFIGSOURCE']._serialized_start=1556
  _globals['_PATHCONFIGSOURCE']._serialized_end=1664
  _globals['_CONFIGSOURCE']._serialized_start=1667
  _globals['_CONFIGSOURCE']._serialized_end=2213
  _globals['_EXTENSIONCONFIGSOURCE']._serialized_start=2216
  _globals['_EXTENSIONCONFIGSOURCE']._serialized_end=2429
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: google/type/phone_number.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'google/type/phone_number.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1egoogle/type/phone_number.proto\x12\x0bgoogle.type\"\xab\x01\n\x0bPhoneNumber\x12\x15\n\x0b\x65\x31\x36\x34_number\x18\x01 \x01(\tH\x00\x12\x38\n\nshort_code\x18\x02 \x01(\x0b\x32\".google.type.PhoneNumber.ShortCodeH\x00\x12\x11\n\textension\x18\x03 \x01(\t\x1a\x30\n\tShortCode\x12\x13\n\x0bregion_code\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\tB\x06\n\x04kindBt\n\x0f\x63om.google.typeB\x10PhoneNumberProtoP\x01ZDgoogle.golang.org/genproto/googleapis/type/phone_number;phone_number\xf8\x01\x01\xa2\x02\x03GTPb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google.type.phone_number_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.google.typeB\020PhoneNumberProtoP\001ZDgoogle.golang.org/genproto/googleapis/type/phone_number;phone_number\370\001\001\242\002\003GTP'
  _globals['_PHONENUMBER']._serialized_start=48
  _globals['_PHONENUMBER']._serialized_end=219
  _globals['_PHONENUMBER_SHORTCODE']._serialized_start=163
  _globals['_PHONENUMBER_SHORTCODE']._serialized_end=211
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/api/v2/auth/common.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/api/v2/auth/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.type.matcher import string_pb2 as envoy_dot_type_dot_matcher_dot_string__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import sensitive_pb2 as udpa_dot_annotations_dot_sensitive__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65nvoy/api/v2/auth/common.proto\x12\x11\x65nvoy.api.v2.auth\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a\x1f\x65nvoy/type/matcher/string.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1eudpa/annotations/migrate.proto\x1a udpa/annotations/sensitive.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc8\x02\n\rTlsParameters\x12\\\n\x1ctls_minimum_protocol_version\x18\x01 \x01(\x0e\x32,.envoy.api.v2.auth.TlsParameters.TlsProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\\\n\x1ctls_maximum_protocol_version\x18\x02 \x01(\x0e\x32,.envoy.api.v2.auth.TlsParameters.TlsProtocolB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x15\n\rcipher_suites\x18\x03 \x03(\t\x12\x13\n\x0b\x65\x63\x64h_curves\x18\x04 \x03(\t\"O\n\x0bTlsProtocol\x12\x0c\n\x08TLS_AUTO\x10\x00\x12\x0b\n\x07TLSv1_0\x10\x01\x12\x0b\n\x07TLSv1_1\x10\x02\x12\x0b\n\x07TLSv1_2\x10\x03\x12\x0b\n\x07TLSv1_3\x10\x04\"\xae\x01\n\x12PrivateKeyProvider\x12\x1e\n\rprovider_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x33\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructB\x08\x18\x01\xb8\xb7\x8b\xa4\x02\x01H\x00\x12\x34\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\x06\xb8\xb7\x8b\xa4\x02\x01H\x00\x42\r\n\x0b\x63onfig_type\"\xfd\x02\n\x0eTlsCertificate\x12\x38\n\x11\x63\x65rtificate_chain\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12:\n\x0bprivate_key\x18\x02 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x43\n\x14private_key_provider\x18\x06 \x01(\x0b\x32%.envoy.api.v2.auth.PrivateKeyProvider\x12\x37\n\x08password\x18\x03 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x06\xb8\xb7\x8b\xa4\x02\x01\x12\x32\n\x0bocsp_staple\x18\x04 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12\x43\n\x1csigned_certificate_timestamp\x18\x05 \x03(\x0b\x32\x1d.envoy.api.v2.core.DataSource\"S\n\x14TlsSessionTicketKeys\x12;\n\x04keys\x18\x01 \x03(\x0b\x32\x1d.envoy.api.v2.core.DataSourceB\x0e\xfa\x42\x05\x92\x01\x02\x08\x01\xb8\xb7\x8b\xa4\x02\x01\"\xaa\x05\n\x1c\x43\x65rtificateValidationContext\x12\x31\n\ntrusted_ca\x18\x01 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12/\n\x17verify_certificate_spki\x18\x03 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\"\x06r\x04 ,(,\x12/\n\x17verify_certificate_hash\x18\x02 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\"\x06r\x04 @(_\x12#\n\x17verify_subject_alt_name\x18\x04 \x03(\tB\x02\x18\x01\x12\x42\n\x17match_subject_alt_names\x18\t \x03(\x0b\x32!.envoy.type.matcher.StringMatcher\x12\x37\n\x13require_ocsp_staple\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12H\n$require_signed_certificate_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x03\x63rl\x18\x07 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSource\x12!\n\x19\x61llow_expired_certificate\x18\x08 \x01(\x08\x12r\n\x18trust_chain_verification\x18\n \x01(\x0e\x32\x46.envoy.api.v2.auth.CertificateValidationContext.TrustChainVerificationB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"F\n\x16TrustChainVerification\x12\x16\n\x12VERIFY_TRUST_CHAIN\x10\x00\x12\x14\n\x10\x41\x43\x43\x45PT_UNTRUSTED\x10\x01\x42\xa3\x01\n\x1fio.envoyproxy.envoy.api.v2.authB\x0b\x43ommonProtoP\x01Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/auth\xf2\x98\xfe\x8f\x05+\x12)envoy.extensions.transport_sockets.tls.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.api.v2.auth.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037io.envoyproxy.envoy.api.v2.authB\013CommonProtoP\001Z8github.com/envoyproxy/go-control-plane/envoy/api/v2/auth\362\230\376\217\005+\022)envoy.extensions.transport_sockets.tls.v3\272\200\310\321\006\002\020\001'
  _globals['_TLSPARAMETERS'].fields_by_name['tls_minimum_protocol_version']._loaded_options = None
  _globals['_TLSPARAMETERS'].fields_by_name['tls_minimum_protocol_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_TLSPARAMETERS'].fields_by_name['tls_maximum_protocol_version']._loaded_options = None
  _globals['_TLSPARAMETERS'].fields_by_name['tls_maximum_protocol_version']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_PRIVATEKEYPROVIDER'].fields_by_name['provider_name']._loaded_options = None
  _globals['_PRIVATEKEYPROVIDER'].fields_by_name['provider_name']._serialized_options = b'\372B\004r\002 \001'
  _globals['_PRIVATEKEYPROVIDER'].fields_by_name['config']._loaded_options = None
  _globals['_PRIVATEKEYPROVIDER'].fields_by_name['config']._serialized_options = b'\030\001\270\267\213\244\002\001'
  _globals['_PRIVATEKEYPROVIDER'].fields_by_name['typed_config']._loaded_options = None
  _globals['_PRIVATEKEYPROVIDER'].fields_by_name['typed_config']._serialized_options = b'\270\267\213\244\002\001'
  _globals['_TLSCERTIFICATE'].fields_by_name['private_key']._loaded_options = None
  _globals['_TLSCERTIFICATE'].fields_by_name['private_key']._serialized_options = b'\270\267\213\244\002\001'
  _globals['_TLSCERTIFICATE'].fields_by_name['password']._loaded_options = None
  _globals['_TLSCERTIFICATE'].fields_by_name['password']._serialized_options = b'\270\267\213\244\002\001'
  _globals['_TLSSESSIONTICKETKEYS'].fields_by_name['keys']._loaded_options = None
  _globals['_TLSSESSIONTICKETKEYS'].fields_by_name['keys']._serialized_options = b'\372B\005\222\001\002\010\001\270\267\213\244\002\001'
  _globals['_CERTIFICATEVALIDATIONCONTEXT'].fields_by_name['verify_certificate_spki']._loaded_options = None
  _globals['_CERTIFICATEVALIDATIONCONTEXT'].fields_by_name['verify_certificate_spki']._serialized_options = b'\372B\013\222\001\010\"\006r\004 ,(,'
  _globals['_CERTIFICATEVALIDATIONCONTEXT'].fields_by_name['verify_certificate_hash']._loaded_options = None
  _globals['_CERTIFICATEVALIDATIONCONTEXT'].fields_by_name['verify_certificate_hash']._serialized_options = b'\372B\013\222\001\010\"\006r\004 @(_'
  _globals['_CERTIFICATEVALIDATIONCONTEXT'].fields_by_name['verify_subject_alt_name']._loaded_options = None
  _globals['_CERTIFICATEVALIDATIONCONTEXT'].fields_by_name['verify_subject_alt_name']._serialized_options = b'\030\001'
  _globals['_CERTIFICATEVALIDATIONCONTEXT'].fields_by_name['trust_chain_verification']._loaded_options = None
  _globals['_CERTIFICATEVALIDATIONCONTEXT'].fields_by_name['trust_chain_verification']._serialized_options = b'\372B\005\202\001\002\020\001'
  _globals['_TLSPARAMETERS']._serialized_start=328
  _globals['_TLSPARAMETERS']._serialized_end=656
  _globals['_TLSPARAMETERS_TLSPROTOCOL']._serialized_start=577
  _globals['_TLSPARAMETERS_TLSPROTOCOL']._serialized_end=656
  _globals['_PRIVATEKEYPROVIDER']._serialized_start=659
  _globals['_PRIVATEKEYPROVIDER']._serialized_end=833
  _globals['_TLSCERTIFICATE']._serialized_start=836
  _globals['_TLSCERTIFICATE']._serialized_end=1217
  _globals['_TLSSESSIONTICKETKEYS']._serialized_start=1219
  _globals['_TLSSESSIONTICKETKEYS']._serialized_end=1302
  _globals['_CERTIFICATEVALIDATIONCONTEXT']._serialized_start=1305
  _globals['_CERTIFICATEVALIDATIONCONTEXT']._serialized_end=1987
  _globals['_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION']._serialized_start=1917
  _globals['_CERTIFICATEVALIDATIONCONTEXT_TRUSTCHAINVERIFICATION']._serialized_end=1987
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/extensions/upstreams/http/v3/http_protocol_options.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/extensions/upstreams/http/v3/http_protocol_options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import extension_pb2 as envoy_dot_config_dot_core_dot_v3_dot_extension__pb2
from envoy.config.core.v3 import protocol_pb2 as envoy_dot_config_dot_core_dot_v3_dot_protocol__pb2
from envoy.extensions.filters.network.http_connection_manager.v3 import http_connection_manager_pb2 as envoy_dot_extensions_dot_filters_dot_network_dot_http__connection__manager_dot_v3_dot_http__connection__manager__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>envoy/extensions/upstreams/http/v3/http_protocol_options.proto\x12\"envoy.extensions.upstreams.http.v3\x1a$envoy/config/core/v3/extension.proto\x1a#envoy/config/core/v3/protocol.proto\x1aYenvoy/extensions/filters/network/http_connection_manager/v3/http_connection_manager.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc4\x0c\n\x13HttpProtocolOptions\x12O\n\x1c\x63ommon_http_protocol_options\x18\x01 \x01(\x0b\x32).envoy.config.core.v3.HttpProtocolOptions\x12Y\n\x1eupstream_http_protocol_options\x18\x02 \x01(\x0b\x32\x31.envoy.config.core.v3.UpstreamHttpProtocolOptions\x12j\n\x14\x65xplicit_http_config\x18\x03 \x01(\x0b\x32J.envoy.extensions.upstreams.http.v3.HttpProtocolOptions.ExplicitHttpConfigH\x00\x12y\n\x1euse_downstream_protocol_config\x18\x04 \x01(\x0b\x32O.envoy.extensions.upstreams.http.v3.HttpProtocolOptions.UseDownstreamHttpConfigH\x00\x12]\n\x0b\x61uto_config\x18\x05 \x01(\x0b\x32\x46.envoy.extensions.upstreams.http.v3.HttpProtocolOptions.AutoHttpConfigH\x00\x12]\n\x0chttp_filters\x18\x06 \x03(\x0b\x32G.envoy.extensions.filters.network.http_connection_manager.v3.HttpFilter\x12L\n\x18header_validation_config\x18\x07 \x01(\x0b\x32*.envoy.config.core.v3.TypedExtensionConfig\x1a\x95\x02\n\x12\x45xplicitHttpConfig\x12K\n\x15http_protocol_options\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.Http1ProtocolOptionsH\x00\x12L\n\x16http2_protocol_options\x18\x02 \x01(\x0b\x32*.envoy.config.core.v3.Http2ProtocolOptionsH\x00\x12L\n\x16http3_protocol_options\x18\x03 \x01(\x0b\x32*.envoy.config.core.v3.Http3ProtocolOptionsH\x00\x42\x16\n\x0fprotocol_config\x12\x03\xf8\x42\x01\x1a\xfc\x01\n\x17UseDownstreamHttpConfig\x12I\n\x15http_protocol_options\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.Http1ProtocolOptions\x12J\n\x16http2_protocol_options\x18\x02 \x01(\x0b\x32*.envoy.config.core.v3.Http2ProtocolOptions\x12J\n\x16http3_protocol_options\x18\x03 \x01(\x0b\x32*.envoy.config.core.v3.Http3ProtocolOptions\x1a\xd4\x02\n\x0e\x41utoHttpConfig\x12I\n\x15http_protocol_options\x18\x01 \x01(\x0b\x32*.envoy.config.core.v3.Http1ProtocolOptions\x12J\n\x16http2_protocol_options\x18\x02 \x01(\x0b\x32*.envoy.config.core.v3.Http2ProtocolOptions\x12J\n\x16http3_protocol_options\x18\x03 \x01(\x0b\x32*.envoy.config.core.v3.Http3ProtocolOptions\x12_\n!alternate_protocols_cache_options\x18\x04 \x01(\x0b\x32\x34.envoy.config.core.v3.AlternateProtocolsCacheOptionsB \n\x19upstream_protocol_options\x12\x03\xf8\x42\x01\x42\xa8\x01\n0io.envoyproxy.envoy.extensions.upstreams.http.v3B\x18HttpProtocolOptionsProtoP\x01ZPgithub.com/envoyproxy/go-control-plane/envoy/extensions/upstreams/http/v3;httpv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.upstreams.http.v3.http_protocol_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0io.envoyproxy.envoy.extensions.upstreams.http.v3B\030HttpProtocolOptionsProtoP\001ZPgithub.com/envoyproxy/go-control-plane/envoy/extensions/upstreams/http/v3;httpv3\272\200\310\321\006\002\020\002'
  _globals['_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG'].oneofs_by_name['protocol_config']._loaded_options = None
  _globals['_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG'].oneofs_by_name['protocol_config']._serialized_options = b'\370B\001'
  _globals['_HTTPPROTOCOLOPTIONS'].oneofs_by_name['upstream_protocol_options']._loaded_options = None
  _globals['_HTTPPROTOCOLOPTIONS'].oneofs_by_name['upstream_protocol_options']._serialized_options = b'\370B\001'
  _globals['_HTTPPROTOCOLOPTIONS']._serialized_start=325
  _globals['_HTTPPROTOCOLOPTIONS']._serialized_end=1929
  _globals['_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG']._serialized_start=1020
  _globals['_HTTPPROTOCOLOPTIONS_EXPLICITHTTPCONFIG']._serialized_end=1297
  _globals['_HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG']._serialized_start=1300
  _globals['_HTTPPROTOCOLOPTIONS_USEDOWNSTREAMHTTPCONFIG']._serialized_end=1552
  _globals['_HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG']._serialized_start=1555
  _globals['_HTTPPROTOCOLOPTIONS_AUTOHTTPCONFIG']._serialized_end=1895
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: envoy/data/tap/v3/transport.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'envoy/data/tap/v3/transport.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.data.tap.v3 import common_pb2 as envoy_dot_data_dot_tap_dot_v3_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!envoy/data/tap/v3/transport.proto\x12\x11\x65nvoy.data.tap.v3\x1a\x1e\x65nvoy/data/tap/v3/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\xae\x04\n\x0bSocketEvent\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x04read\x18\x02 \x01(\x0b\x32#.envoy.data.tap.v3.SocketEvent.ReadH\x00\x12\x35\n\x05write\x18\x03 \x01(\x0b\x32$.envoy.data.tap.v3.SocketEvent.WriteH\x00\x12\x37\n\x06\x63losed\x18\x04 \x01(\x0b\x32%.envoy.data.tap.v3.SocketEvent.ClosedH\x00\x1a]\n\x04Read\x12%\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.envoy.data.tap.v3.Body:.\x9a\xc5\x88\x1e)\n\'envoy.data.tap.v2alpha.SocketEvent.Read\x1as\n\x05Write\x12%\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.envoy.data.tap.v3.Body\x12\x12\n\nend_stream\x18\x02 \x01(\x08:/\x9a\xc5\x88\x1e*\n(envoy.data.tap.v2alpha.SocketEvent.Write\x1a:\n\x06\x43losed:0\x9a\xc5\x88\x1e+\n)envoy.data.tap.v2alpha.SocketEvent.Closed:)\x9a\xc5\x88\x1e$\n\"envoy.data.tap.v2alpha.SocketEventB\x10\n\x0e\x65vent_selector\"\xee\x01\n\x13SocketBufferedTrace\x12\x10\n\x08trace_id\x18\x01 \x01(\x04\x12\x31\n\nconnection\x18\x02 \x01(\x0b\x32\x1d.envoy.data.tap.v3.Connection\x12.\n\x06\x65vents\x18\x03 \x03(\x0b\x32\x1e.envoy.data.tap.v3.SocketEvent\x12\x16\n\x0eread_truncated\x18\x04 \x01(\x08\x12\x17\n\x0fwrite_truncated\x18\x05 \x01(\x08:1\x9a\xc5\x88\x1e,\n*envoy.data.tap.v2alpha.SocketBufferedTrace\"\xdf\x01\n\x1aSocketStreamedTraceSegment\x12\x10\n\x08trace_id\x18\x01 \x01(\x04\x12\x33\n\nconnection\x18\x02 \x01(\x0b\x32\x1d.envoy.data.tap.v3.ConnectionH\x00\x12/\n\x05\x65vent\x18\x03 \x01(\x0b\x32\x1e.envoy.data.tap.v3.SocketEventH\x00:8\x9a\xc5\x88\x1e\x33\n1envoy.data.tap.v2alpha.SocketStreamedTraceSegmentB\x0f\n\rmessage_pieceB{\n\x1fio.envoyproxy.envoy.data.tap.v3B\x0eTransportProtoP\x01Z>github.com/envoyproxy/go-control-plane/envoy/data/tap/v3;tapv3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.data.tap.v3.transport_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037io.envoyproxy.envoy.data.tap.v3B\016TransportProtoP\001Z>github.com/envoyproxy/go-control-plane/envoy/data/tap/v3;tapv3\272\200\310\321\006\002\020\002'
  _globals['_SOCKETEVENT_READ']._loaded_options = None
  _globals['_SOCKETEVENT_READ']._serialized_options = b'\232\305\210\036)\n\'envoy.data.tap.v2alpha.SocketEvent.Read'
  _globals['_SOCKETEVENT_WRITE']._loaded_options = None
  _globals['_SOCKETEVENT_WRITE']._serialized_options = b'\232\305\210\036*\n(envoy.data.tap.v2alpha.SocketEvent.Write'
  _globals['_SOCKETEVENT_CLOSED']._loaded_options = None
  _globals['_SOCKETEVENT_CLOSED']._serialized_options = b'\232\305\210\036+\n)envoy.data.tap.v2alpha.SocketEvent.Closed'
  _globals['_SOCKETEVENT']._loaded_options = None
  _globals['_SOCKETEVENT']._serialized_options = b'\232\305\210\036$\n\"envoy.data.tap.v2alpha.SocketEvent'
  _globals['_SOCKETBUFFEREDTRACE']._loaded_options = None
  _globals['_SOCKETBUFFEREDTRACE']._serialized_options = b'\232\305\210\036,\n*envoy.data.tap.v2alpha.SocketBufferedTrace'
  _globals['_SOCKETSTREAMEDTRACESEGMENT']._loaded_options = None
  _globals['_SOCKETSTREAMEDTRACESEGMENT']._serialized_options = b'\232\305\210\0363\n1envoy.data.tap.v2alpha.SocketStreamedTraceSegment'
  _globals['_SOCKETEVENT']._serialized_start=188
  _globals['_SOCKETEVENT']._serialized_end=746
  _globals['_SOCKETEVENT_READ']._serialized_start=415
  _globals['_SOCKETEVENT_READ']._serialized_end=508
  _globals['_SOCKETEVENT_WRITE']._serialized_start=510
  _globals['_SOCKETEVENT_WRITE']._serialized_end=625
  _globals['_SOCKETEVENT_CLOSED']._serialized_start=627
  _globals['_SOCKETEVENT_CLOSED']._serialized_end=685
  _globals['_SOCKETBUFFEREDTRACE']._serialized_start=749
  _globals['_SOCKETBUFFEREDTRACE']._serialized_end=987
  _globals['_SOCKETSTREAMEDTRACESEGMENT']._serialized_start=990
  _globals['_SOCKETSTREAMEDTRACESEGMENT']._serialized_end=1213
# @@protoc_insertion_point(module_scope)
